/* * * Sdg_Lex.h * * *
 * Sdg_Lexer
 * * * * * * * * * * */
#ifndef _SDG_LEX_H_
#define _SDG_LEX_H_

#ifndef FLEXFIX
#define FLEXFIX YY_Sdg_Parser_STYPE *val
#define FLEXFIX2 val
#endif

#ifndef YY_DECL
#define YY_DECL int Sdg_Lexer::yylex(YY_Sdg_Parser_STYPE *val)
#endif

#include"Sdg_Base.h"
#include"Sdg_Script.h"
#include"Sdg_Yacc.h"

class Sdg_Lexer : public yyFlexLexer, public Sdg_Base{
 public:
	Sdg_Lexer(std::istream &file):Sdg_Base("Sdg_Lexer"){switch_streams(&file,&std::cout); yy_flex_debug = 1; }
	virtual ~Sdg_Lexer(){ }
	virtual int yylex(FLEXFIX);
 protected:
	void LexerError(const char* msg){Error("%d:%s\n",yylineno,msg);}
};

#endif
